let config = null;
$.getJSON("Build/Static/js/config.json", "", function (data) {
    config = data;
    $(document).ready(function () {
        initialize();
    });
});

function initialize() {
    let TDTVec = new Cesium.WebMapTileServiceImageryProvider({
        name: config.TDTVec.name,
        url: config.TDTVec.url,
        layer: config.TDTVec.layer,
        style: config.TDTVec.style,
        format: config.TDTVec.format,
        tileMatrixSetID: config.TDTVec.tileMatrixSetID,
        minimumLevel: config.TDTVec.minimumLevel,
        maximumLevel: config.TDTVec.maximumLevel,
    });
    let ESRIImg = new Cesium.ImageryLayer(new Cesium.ArcGisMapServerImageryProvider({
        name: config.ESRIImg.name,
        url: config.ESRIImg.url,
        layer: config.ESRIImg.layer,
        style: config.ESRIImg.style,
        format: config.ESRIImg.format,
        tileMatrixSetID: config.ESRIImg.tileMatrixSetID,
        minimumLevel: config.ESRIImg.minimumLevel,
        maximumLevel: config.ESRIImg.maximumLevel,
        enablePickFeatures: config.ESRIImg.enablePickFeatures,
    }), {
        show: config.ESRIImg.show
    });
    viewer = new Cesium.Viewer('mainScene', {
        sceneMode: Cesium.SceneMode.SCENE3D,
        scene3DOnly: true,
        fullscreenButton: false,
        homeButton: false,
        animation: false,
        baseLayerPicker: false,
        geocoder: false,
        timeline: false,
        sceneModePicker: false,
        navigationHelpButton: false,
        selectionIndicator: false,
        infoBox: false,
        imageryProvider: TDTVec,
        contextOptions: {
            webgl: {
                alpha: true,
                depth: false,
                stencil: true,
                antialias: true,
                premultipliedAlpha: true,
                preserveDrawingBuffer: true,
                failIfMajorPerformanceCaveat: true
            }
        },
        skyBox: new Cesium.SkyBox({
            sources: {
                // positiveX: 'Build/Cseium/Assets/Textures/SkyBox/tycho2t3_80_px.jpg',
                // negativeX: 'Build/Cseium/Assets/Textures/SkyBox/tycho2t3_80_mx.jpg',
                // positiveY: 'Build/Cseium/Assets/Textures/SkyBox/tycho2t3_80_py.jpg',
                // negativeY: 'Build/Cseium/Assets/Textures/SkyBox/tycho2t3_80_my.jpg',
                // positiveZ: 'Build/Cseium/Assets/Textures/SkyBox/tycho2t3_80_pz.jpg',
                // negativeZ: 'Build/Cseium/Assets/Textures/SkyBox/tycho2t3_80_mz.jpg',
                positiveX: 'Build/Cseium/Assets/Textures/SkyBox/sky.jpg',
                negativeX: 'Build/Cseium/Assets/Textures/SkyBox/sky.jpg',
                positiveY: 'Build/Cseium/Assets/Textures/SkyBox/sky.jpg',
                negativeY: 'Build/Cseium/Assets/Textures/SkyBox/sky.jpg',
                positiveZ: 'Build/Cseium/Assets/Textures/SkyBox/sky.jpg',
                negativeZ: 'Build/Cseium/Assets/Textures/SkyBox/sky.jpg'
            }
        }),
    });
    Cesium.viewerCesiumNavigationMixin(viewer, {
        enableCompass: true,
        enableZoomControls: true,
        enableDistanceLegend: true,
        enableCompassOuterRing: true,
        defaultPositionView: {
            destination: new Cesium.Cartesian3(-1715484.7827782272, 4993631.649357889, 3566335.65416271),
            orientation: new Cesium.HeadingPitchRoll(0.011790760377941467, -0.49775987933742005, 0.000041929085810465955)
        }
    });
    viewer.scene.moon.show = false;
    viewer.imageryLayers.add(ESRIImg);
    viewer.scene.screenSpaceCameraController.enableLook = false;
    viewer.scene.screenSpaceCameraController.enableTranslate = false;
    viewer.cesiumWidget.creditContainer.style.display = "none";
    viewer.scene.globe.baseColor = Cesium.Color.fromCssColorString(config.globe.baseColor);
    viewer.cesiumWidget.screenSpaceEventHandler.removeInputAction(Cesium.ScreenSpaceEventType.LEFT_DOUBLE_CLICK);
    let tileset = viewer.scene.primitives.add(new Cesium.Cesium3DTileset({
        // url: '../../../../Data/Tile/3DTiles/dayanta/',
        url: config.MainModelData.photography.url,
        colorBlendMode: Cesium.Cesium3DTileColorBlendMode.HIGHLIGHT
    }));
    tileset.readyPromise.then(function (tileset) {
        // viewer.camera.viewBoundingSphere(tileset.boundingSphere, new Cesium.HeadingPitchRange(0, -45, 0));
        // viewer.camera.lookAtTransform(Cesium.Matrix4.IDENTITY);
        let x = config.MainModelData.photography.offset.x, y = config.MainModelData.photography.offset.y,
            z = config.MainModelData.photography.offset.z;
        let boundingSphere = tileset.boundingSphere;
        let cartographic = Cesium.Cartographic.fromCartesian(boundingSphere.center);
        let surface = Cesium.Cartesian3.fromRadians(cartographic.longitude, cartographic.latitude, 0.0);
        let offset = Cesium.Cartesian3.fromRadians((cartographic.longitude + x), (cartographic.latitude + y), z);
        let translation = Cesium.Cartesian3.subtract(offset, surface, new Cesium.Cartesian3());
        tileset.modelMatrix = Cesium.Matrix4.fromTranslation(translation);

    });
    viewer.camera.setView({
        destination: new Cesium.Cartesian3(-1715484.7827782272, 4993631.649357889, 3566335.65416271),
        orientation: new Cesium.HeadingPitchRoll(0.011790760377941467, -0.49775987933742005, 0.000041929085810465955)
    });
}